/*
 * Copyright (C) 2016 Chi Vinh Le and contributors.
 *
 * This software may be modified and distributed under the terms
 * of the MIT license. See the LICENSE file for details.
 */
"use strict";
/**
 * A class for adding content chunks and retrieving files from added chunks.
 */
var WebpackContentChunks = (function () {
    /**
     * @param {Object} stats - Webpack stats.
     */
    function WebpackContentChunks(stats) {
        this.modules = {};
        this.files = [];
        this.analyzeStats(stats);
    }
    /**
     * Adds all content chunks that originated from the nth-codesplit in
     * given module.
     * @param {string} moduleName - Name of module, can be obtained using node's __filename feature.
     * @param {number} codeSplit - Defines nth-codesplit starting at 0.
     */
    WebpackContentChunks.prototype.addChunksFrom = function (moduleName, codeSplit) {
        if (moduleName.substr(0, 2) !== "./") {
            moduleName = "./" + moduleName;
        }
        var files = this.modules[moduleName].codeSplits[codeSplit].files;
        (_a = this.files).push.apply(_a, files);
        var _a;
    };
    /**
     * Returns an array of files from added chunks.
     * @returns {string[]} - Array of files.
     */
    WebpackContentChunks.prototype.getFiles = function () {
        return this.files;
    };
    /**
     * Resets instance as if no chunks has been added.
     */
    WebpackContentChunks.prototype.reset = function () {
        this.files = [];
    };
    WebpackContentChunks.prototype.analyzeStats = function (stats) {
        for (var _i = 0, _a = stats.chunks; _i < _a.length; _i++) {
            var chunk = _a[_i];
            for (var _b = 0, _c = chunk.origins; _b < _c.length; _b++) {
                var origin = _c[_b];
                var moduleName = origin.moduleName;
                var line = origin.loc.split(":")[0];
                if (!this.modules[moduleName]) {
                    this.modules[moduleName] = new Module();
                }
                this.modules[moduleName].add(chunk.files, line);
            }
        }
    };
    return WebpackContentChunks;
}());
exports.WebpackContentChunks = WebpackContentChunks;
var Module = (function () {
    function Module() {
        this.codeSplits = [];
    }
    Module.prototype.add = function (files, line) {
        for (var _i = 0, _a = this.codeSplits; _i < _a.length; _i++) {
            var cs = _a[_i];
            if (cs.line === line) {
                (_b = cs.files).push.apply(_b, files);
                return;
            }
        }
        this.codeSplits.push({ files: files.slice(), line: line });
        var _b;
    };
    return Module;
}());
